@@ -14,10 +14,10 @@ from .recorder import Betamax
 from .matchers import BaseMatcher
 from .serializers import BaseSerializer
 
-__all__ = [BetamaxError, Betamax, BaseMatcher, BaseSerializer]
+__all__ = ('BetamaxError', 'Betamax', 'BaseMatcher', 'BaseSerializer')
 __author__ = 'Ian Cordasco'
 __copyright__ = 'Copyright 2013 Ian Cordasco'
 __license__ = 'Apache 2.0'
 __title__ = 'betamax'
-__version__ = '0.3.2'
+__version__ = '0.4.0'
 __version_info__ = tuple(int(i) for i in __version__.split('.'))
